Welcome to the Lewis documentation!
===================================

Lewis is a Python package that makes it easy to develop complex stateful device simulations. It
is licensed under GPL version 3 and the source is available on github_, where you are welcome to
open new issues so the package can improve.

If you're new to Lewis reading the :doc:`user_guide/index` is a good start. Once you plan
on writing your own device it's time to go through the :doc:`developer_guide/index`.
The :doc:`api/index` can also help with that.

Documentation contents:

.. toctree::
   :maxdepth: 2

   quickstart_guide/index
   user_guide/index
   developer_guide/index
   api/index
   release_notes/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

.. _github: https://github.com/ess-dmsc/lewis

